/**
 * @file
 * Facets form helper.
 *
 * We use the Form API #states processor to recursively check checkboxes.
 * However, this introduces a small issue when a user want to *only* check a
 * child checkbox. Because the parent is not checked, upon page load the child
 * will be unchecked. The following code circumvents this behavior by simply
 * checking the box again after page load.
 */

(function($, Drupal) {
  'use strict';

  Drupal.behaviors.dsbPortalFacets = {

    attach: function(context, settings) {
      var $checkboxes = $('input[name^="filter["][checked]', context);
      if ($checkboxes.length) {
        // The found checkboxes are checked in HTML; they may not be for the
        // browser. Check them again.
        $checkboxes.attr('checked', true);
      }
    }

  };

})(jQuery, Drupal);
